@@ -1,4 +1,5 @@
-use crate::date_utils;
+use crate::date_utils as GitQLDate;
+use crate::regex_utils as GitQLRegex;
 use crate::types::DataType;
 use crate::value::Value;
 
@@ -46,6 +47,7 @@ lazy_static! {
         map.insert("quotename", text_quotename);
 
         // Date functions
+        map.insert("date", date_extract_date);
         map.insert("current_date", date_current_date);
         map.insert("current_time", date_current_time);
         map.insert("current_timestamp", date_current_timestamp);
@@ -56,13 +58,19 @@ lazy_static! {
         map.insert("dayname", date_dayname);
         map.insert("monthname", date_monthname);
         map.insert("hour", date_hour);
+        map.insert("minute", date_minute);
         map.insert("isdate", date_is_date);
         map.insert("dayofweek", date_day_of_week);
         map.insert("dayofmonth", date_day_of_month);
         map.insert("dayofyear", date_day_of_year);
+        map.insert("weekofyear", date_week_of_year);
         map.insert("quarter", date_quarter);
         map.insert("year", date_year);
+        map.insert("month", date_month);
+        map.insert("weekday", date_weekday);
         map.insert("to_days", date_to_days);
+        map.insert("last_day", date_last_day);
+        map.insert("yearweek", date_year_and_week);
 
         // Numeric functions
         map.insert("abs", numeric_abs);
@@ -86,6 +94,12 @@ lazy_static! {
         map.insert("typeof", general_type_of);
         map.insert("greatest", general_greatest);
         map.insert("least", general_least);
+
+        // Regex Functions
+        map.insert("regexp_instr", regexp_instr);
+        map.insert("regexp_like", regexp_like);
+        map.insert("regexp_replace", regexp_replace);
+        map.insert("regexp_substr", regexp_substr);
         map
     };
 }
@@ -272,6 +286,13 @@ lazy_static! {
         );
 
         // Date functions
+        map.insert(
+            "date",
+            Prototype {
+                parameters: vec![DataType::Variant(vec![DataType::Date, DataType::DateTime])],
+                result: DataType::Date,
+            },
+        );
         map.insert(
             "current_date",
             Prototype {
@@ -342,6 +363,13 @@ lazy_static! {
                 result: DataType::Integer,
             }
         );
+        map.insert(
+            "minute",
+            Prototype {
+                parameters: vec![DataType::DateTime],
+                result: DataType::Integer,
+            }
+        );
         map.insert(
             "isdate",
             Prototype {
@@ -370,6 +398,13 @@ lazy_static! {
                 result: DataType::Integer,
             }
         );
+        map.insert(
+            "weekofyear",
+            Prototype {
+                parameters: vec![DataType::Date],
+                result: DataType::Integer,
+            }
+        );
         map.insert(
             "quarter",
             Prototype {
@@ -384,6 +419,20 @@ lazy_static! {
                 result: DataType::Integer,
             }
         );
+        map.insert(
+            "month",
+            Prototype {
+                parameters: vec![DataType::Date],
+                result: DataType::Integer,
+            }
+        );
+        map.insert(
+            "weekday",
+            Prototype {
+                parameters: vec![DataType::Date],
+                result: DataType::Integer,
+            }
+        );
         map.insert(
             "to_days",
             Prototype {
@@ -391,6 +440,20 @@ lazy_static! {
                 result: DataType::Integer,
             }
         );
+        map.insert(
+            "last_day",
+            Prototype {
+                parameters: vec![DataType::Date],
+                result: DataType::Date,
+            }
+        );
+        map.insert(
+            "yearweek",
+            Prototype {
+                parameters: vec![DataType::Date],
+                result: DataType::Text,
+            }
+        );
         // Numeric functions
         map.insert(
             "abs",
@@ -526,6 +589,36 @@ lazy_static! {
                 result: DataType::Any
              },
         );
+
+        // Regex functions
+        map.insert(
+            "regexp_instr",
+            Prototype {
+                parameters: vec![DataType::Text, DataType::Text],
+                result: DataType::Integer,
+            },
+        );
+        map.insert(
+            "regexp_like",
+            Prototype {
+                parameters: vec![DataType::Text, DataType::Text],
+                result: DataType::Integer,
+            },
+        );
+        map.insert(
+            "regexp_replace",
+            Prototype {
+                parameters: vec![DataType::Text, DataType::Text, DataType::Text],
+                result: DataType::Text,
+            },
+        );
+        map.insert(
+            "regexp_substr",
+            Prototype {
+                parameters: vec![DataType::Text, DataType::Text],
+                result: DataType::Text,
+            },
+        );
         map
     };
 }
@@ -792,27 +885,35 @@ fn text_quotename(inputs: &[Value]) -> Value {
 }
 
 // Date functions
+fn date_extract_date(inputs: &[Value]) -> Value {
+    let argument_type = inputs[0].data_type();
+    if argument_type.is_date() {
+        return inputs[0].clone();
+    }
+    let timestamp = inputs[0].as_date_time();
+    Value::Date(timestamp)
+}
 
 fn date_current_date(_inputs: &[Value]) -> Value {
-    let time_stamp = date_utils::get_unix_timestamp_ms();
+    let time_stamp = GitQLDate::get_unix_timestamp_ms();
     Value::Date(time_stamp)
 }
 
 fn date_current_time(_inputs: &[Value]) -> Value {
-    let time_stamp = date_utils::get_unix_timestamp_ms();
-    let time = date_utils::time_stamp_to_time(time_stamp);
+    let time_stamp = GitQLDate::get_unix_timestamp_ms();
+    let time = GitQLDate::time_stamp_to_time(time_stamp);
     Value::Time(time)
 }
 
 fn date_current_timestamp(_inputs: &[Value]) -> Value {
-    let time_stamp = date_utils::get_unix_timestamp_ms();
+    let time_stamp = GitQLDate::get_unix_timestamp_ms();
     Value::DateTime(time_stamp)
 }
 
 fn date_make_date(inputs: &[Value]) -> Value {
     let year = inputs[0].as_int() as i32;
     let day_of_year = inputs[1].as_int() as u32;
-    let time_stamp = date_utils::time_stamp_from_year_and_day(year, day_of_year);
+    let time_stamp = GitQLDate::time_stamp_from_year_and_day(year, day_of_year);
     Value::Date(time_stamp)
 }
 
@@ -825,59 +926,92 @@ fn date_make_time(inputs: &[Value]) -> Value {
 
 fn date_day(inputs: &[Value]) -> Value {
     let date = inputs[0].as_date();
-    Value::Integer(date_utils::date_to_day_number_in_month(date).into())
+    Value::Integer(GitQLDate::date_to_day_number_in_month(date).into())
 }
 
 fn date_dayname(inputs: &[Value]) -> Value {
     let date = inputs[0].as_date();
-    let date_str = date_utils::date_to_day_name(date);
+    let date_str = GitQLDate::date_to_day_name(date);
     Value::Text(date_str)
 }
 
 fn date_monthname(inputs: &[Value]) -> Value {
     let date = inputs[0].as_date();
-    let month_str = date_utils::date_to_month_name(date);
+    let month_str = GitQLDate::date_to_month_name(date);
     Value::Text(month_str)
 }
 
 fn date_hour(inputs: &[Value]) -> Value {
     let date = inputs[0].as_date_time();
-    let hour = date_utils::date_time_to_hour(date);
+    let hour = GitQLDate::date_time_to_hour(date);
     Value::Integer(hour)
 }
 
+fn date_minute(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date_time();
+    let minute = GitQLDate::date_time_to_minute(date);
+    Value::Integer(minute)
+}
+
 fn date_is_date(inputs: &[Value]) -> Value {
     Value::Boolean(inputs[0].data_type().is_date())
 }
 
 fn date_day_of_week(inputs: &[Value]) -> Value {
     let date = inputs[0].as_date();
-    Value::Integer(date_utils::date_to_day_number_in_week(date).into())
+    Value::Integer(GitQLDate::date_to_day_number_in_week(date).into())
 }
 
 fn date_day_of_month(inputs: &[Value]) -> Value {
     let date = inputs[0].as_date();
-    Value::Integer(date_utils::date_to_day_number_in_month(date).into())
+    Value::Integer(GitQLDate::date_to_day_number_in_month(date).into())
 }
 
 fn date_day_of_year(inputs: &[Value]) -> Value {
     let date = inputs[0].as_date();
-    Value::Integer(date_utils::date_to_day_number_in_year(date).into())
+    Value::Integer(GitQLDate::date_to_day_number_in_year(date).into())
+}
+
+fn date_week_of_year(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date();
+    Value::Integer(GitQLDate::date_to_week_number_in_year(date).into())
+}
+
+fn date_year_and_week(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date();
+    let year = GitQLDate::date_to_year(date);
+    let week_number = GitQLDate::date_to_week_number_in_year(date);
+    Value::Text(format!("{}{}", year, week_number))
 }
 
 fn date_quarter(inputs: &[Value]) -> Value {
     let date = inputs[0].as_date();
-    Value::Integer(date_utils::date_to_quarter_index(date))
+    Value::Integer(GitQLDate::date_to_quarter_index(date))
 }
 
 fn date_year(inputs: &[Value]) -> Value {
     let date = inputs[0].as_date();
-    Value::Integer(date_utils::date_to_year(date).into())
+    Value::Integer(GitQLDate::date_to_year(date).into())
+}
+
+fn date_month(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date();
+    Value::Integer(GitQLDate::date_to_month(date).into())
+}
+
+fn date_weekday(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date();
+    Value::Integer(GitQLDate::date_to_weekday(date).into())
 }
 
 fn date_to_days(inputs: &[Value]) -> Value {
     let date = inputs[0].as_date();
-    Value::Integer(date_utils::date_to_days_count(date))
+    Value::Integer(GitQLDate::date_to_days_count(date))
+}
+
+fn date_last_day(inputs: &[Value]) -> Value {
+    let date = inputs[0].as_date();
+    Value::Date(GitQLDate::date_last_day(date))
 }
 
 // Numeric functions
@@ -1016,3 +1150,35 @@ fn general_least(inputs: &[Value]) -> Value {
 
     least.to_owned()
 }
+
+// Regex functions
+
+fn regexp_instr(inputs: &[Value]) -> Value {
+    let input = inputs[0].as_text();
+    let pattern = inputs[1].as_text();
+    let position = GitQLRegex::regexp_pattern_position(&input, &pattern);
+    Value::Integer(position)
+}
+
+fn regexp_like(inputs: &[Value]) -> Value {
+    let input = inputs[0].as_text();
+    let pattern = inputs[1].as_text();
+    Value::Integer(if GitQLRegex::regex_is_match(&input, &pattern) {
+        1
+    } else {
+        0
+    })
+}
+
+fn regexp_replace(inputs: &[Value]) -> Value {
+    let input = inputs[0].as_text();
+    let pattern = inputs[1].as_text();
+    let replacement = inputs[2].as_text();
+    Value::Text(GitQLRegex::regex_replace(&input, &pattern, &replacement))
+}
+
+fn regexp_substr(inputs: &[Value]) -> Value {
+    let input = inputs[0].as_text();
+    let pattern = inputs[1].as_text();
+    Value::Text(GitQLRegex::regex_substr(&input, &pattern))
+}
