@@ -29,6 +29,8 @@ pub fn parse_gql(tokens: Vec<Token>, env: &mut Environment) -> Result<Query, Box
     let query_result = match &first_token.kind {
         TokenKind::Set => parse_set_query(env, &tokens, &mut position),
         TokenKind::Select => parse_select_query(env, &tokens, &mut position),
+        TokenKind::Describe => parse_describe_query(env, &tokens, &mut position),
+        TokenKind::Show => parse_show_query(env, &tokens, &mut position),
         _ => Err(un_expected_statement_error(&tokens, &mut position)),
     };
 
@@ -107,6 +109,54 @@ fn parse_set_query(
     }))
 }
 
+fn parse_describe_query(
+    _: &mut Environment,
+    tokens: &[Token],
+    position: &mut usize,
+) -> Result<Query, Box<Diagnostic>> {
+    let len = tokens.len();
+
+    // Consume Set keyword
+    *position += 1;
+
+    if *position >= len || tokens[*position].kind != TokenKind::Symbol {
+        return Err(Diagnostic::error("Expect table name after DESC Statement")
+            .with_location(get_safe_location(tokens, *position - 1))
+            .as_boxed());
+    }
+
+    let name = &tokens[*position].literal;
+
+    *position += 1;
+
+    Ok(Query::Describe(DescribeStatement {
+        table_name: name.to_string(),
+    }))
+}
+
+fn parse_show_query(
+    _: &mut Environment,
+    tokens: &[Token],
+    position: &mut usize,
+) -> Result<Query, Box<Diagnostic>> {
+    let len = tokens.len();
+
+    // lets advance
+    *position += 1;
+
+    if *position >= len || tokens[*position].literal != "tables" {
+        return Err(
+            Diagnostic::error("Show can not be followed by names other than tables")
+                .with_location(get_safe_location(tokens, *position - 1))
+                .as_boxed(),
+        );
+    }
+
+    *position += 1;
+
+    Ok(Query::ShowTables)
+}
+
 fn parse_select_query(
     env: &mut Environment,
     tokens: &[Token],
@@ -1698,7 +1748,7 @@ fn parse_arguments_expressions(
     if consume_kind(tokens, *position, TokenKind::LeftParen).is_ok() {
         *position += 1;
 
-        while tokens[*position].kind != TokenKind::RightParen {
+        while *position < tokens.len() && tokens[*position].kind != TokenKind::RightParen {
             let argument = parse_expression(context, env, tokens, position)?;
             let argument_literal = get_expression_name(&argument);
             if argument_literal.is_ok() {
@@ -1708,7 +1758,7 @@ fn parse_arguments_expressions(
 
             arguments.push(argument);
 
-            if tokens[*position].kind == TokenKind::Comma {
+            if *position < tokens.len() && tokens[*position].kind == TokenKind::Comma {
                 *position += 1;
             } else {
                 break;
@@ -2155,7 +2205,7 @@ fn un_expected_expression_error(tokens: &[Token], position: &usize) -> Box<Diagn
             .as_boxed();
     }
 
-    // `< =` the user may mean to write `<=`
+    // `> =` the user may mean to write `>=`
     if previous.kind == TokenKind::Greater && current.kind == TokenKind::Equal {
         return Diagnostic::error("Unexpected `> =`, do you mean `>=`?")
             .add_help("Try to remove space between `> =`")
@@ -2163,7 +2213,7 @@ fn un_expected_expression_error(tokens: &[Token], position: &usize) -> Box<Diagn
             .as_boxed();
     }
 
-    // `> =` the user may mean to write `>=`
+    // `< =` the user may mean to write `<=`
     if previous.kind == TokenKind::Less && current.kind == TokenKind::Equal {
         return Diagnostic::error("Unexpected `< =`, do you mean `<=`?")
             .add_help("Try to remove space between `< =`")
@@ -2195,6 +2245,14 @@ fn un_expected_expression_error(tokens: &[Token], position: &usize) -> Box<Diagn
             .as_boxed();
     }
 
+    // `<= >` the user may mean to write `<=>`
+    if previous.kind == TokenKind::LessEqual && current.kind == TokenKind::Greater {
+        return Diagnostic::error("Unexpected `<= >`, do you mean `<=>`?")
+            .add_help("Try to remove space between `<= >`")
+            .with_location(location)
+            .as_boxed();
+    }
+
     // Default error message
     Diagnostic::error("Can't complete parsing this expression")
         .with_location(location)
