@@ -1,5 +1,9 @@
 use atty::Stream;
+use git_data_provider::GitDataProvider;
+use git_schema::TABLES_FIELDS_NAMES;
+use git_schema::TABLES_FIELDS_TYPES;
 use gitql_ast::environment::Environment;
+use gitql_ast::schema::Schema;
 use gitql_cli::arguments;
 use gitql_cli::arguments::Arguments;
 use gitql_cli::arguments::Command;
@@ -7,19 +11,23 @@ use gitql_cli::arguments::OutputFormat;
 use gitql_cli::diagnostic_reporter;
 use gitql_cli::diagnostic_reporter::DiagnosticReporter;
 use gitql_cli::render;
+use gitql_engine::data_provider::DataProvider;
 use gitql_engine::engine;
 use gitql_engine::engine::EvaluationResult::SelectedGroups;
 use gitql_parser::diagnostic::Diagnostic;
 use gitql_parser::parser;
 use gitql_parser::tokenizer;
 
+mod git_data_provider;
+mod git_schema;
+
 fn main() {
     if cfg!(debug_assertions) {
         std::env::set_var("RUST_BACKTRACE", "1");
         std::env::set_var("RUST_LIB_BACKTRACE", "1");
     }
 
-    let args = std::env::args().collect();
+    let args: Vec<String> = std::env::args().collect();
     let command = arguments::parse_arguments(&args);
 
     match command {
@@ -38,7 +46,11 @@ fn main() {
             }
 
             let repos = git_repos_result.ok().unwrap();
-            let mut env = Environment::default();
+            let schema = Schema {
+                tables_fields_names: TABLES_FIELDS_NAMES.to_owned(),
+                tables_fields_types: TABLES_FIELDS_TYPES.to_owned(),
+            };
+            let mut env = Environment::new(schema);
             execute_gitql_query(query, &arguments, &repos, &mut env, &mut reporter);
         }
         Command::Help => {
@@ -64,7 +76,12 @@ fn launch_gitql_repl(arguments: Arguments) {
         return;
     }
 
-    let mut global_env = Environment::default();
+    let schema = Schema {
+        tables_fields_names: TABLES_FIELDS_NAMES.to_owned(),
+        tables_fields_types: TABLES_FIELDS_TYPES.to_owned(),
+    };
+
+    let mut global_env = Environment::new(schema);
     let git_repositories = git_repos_result.ok().unwrap();
 
     let mut input = String::new();
@@ -141,7 +158,8 @@ fn execute_gitql_query(
     let front_duration = front_start.elapsed();
 
     let engine_start = std::time::Instant::now();
-    let evaluation_result = engine::evaluate(env, repos, query_node);
+    let provider: Box<dyn DataProvider> = Box::new(GitDataProvider::new(repos.to_vec()));
+    let evaluation_result = engine::evaluate(env, &provider, query_node);
 
     // Report Runtime exceptions if they exists
     if evaluation_result.is_err() {
